import re
import logging
import requests
from typing import Dict

from . import config


class ScoresScraper:
    def __init__(self):
        pass

    def get_scores(event_id: str) -> Dict:
        """
        Gets the latest scores update for an event if found

        :param event_id: the id of the live event
        :returns: a dictionary with latest event scores
        """
        ### EXTRACT API KEY ###
        response = requests.get(config.MAIN_URL)
        api_key = re.findall(re.compile('"appKey":\s*"(.+?)"'), response.text)

        if not api_key:
            logging.error("Could not find API key")
            return None

        ### GET LIVE SCORES ###
        response = requests.get(
            config.API_URL.format(api_key=api_key, events_ids=event_id)
        )
        payload = response.json()

        if not payload:
            logging.info(f"No scores found for event with id: {event_id}")
            return None

        return payload[0]
